---
name: Bug report
about: Create a report to help us improve
title: ""
labels: "🐞 bug"
assignees: ""
---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

1. Install `boto34[...]`
2. Run `mypy`/`pyright` on the following code sample

```python
import boto3

...
```

**Actual output**

```
...
```

**Expected output**

```
...
```

**Additional context**
Your OS, `boto34` installation method, `boto3` version, etc.
